@@ -22,6 +22,7 @@ import time
 from datetime import datetime
 import matplotlib.pyplot as plt
 import seaborn as sns
+import lightgbm as lgb 
 #import core_helper.helper_plot as hp
 #import src.Prj_Core.core_helper.helper_plot as hp
 from data_science_helper import helper_plot as hp
@@ -91,7 +92,11 @@ def generar_reporte(model,y_prob_uno, X_test, y_test,url,print_consola):
     
 def predecir_clasificacion_binaria(model, X=None, umbral=0.5):
     print("inicio predecir_clasificacion_binaria")
-    if  isinstance(model, list)==False:    
+    
+    if type(model)==lgb.basic.Booster:
+        y_prob_uno = model.predict(X, num_iteration=model.best_iteration)      
+        
+    elif  isinstance(model, list)==False:    
         predicted_probas = model.predict_proba(X)
         y_prob_uno = predicted_probas[:,1]
     else:
